@@ -204,6 +204,8 @@ verifyHostname, VerificationError = _selectVerifyImplementation(OpenSSL)
 
 
 from zope.interface import Interface, implementer
+from constantly import Flags, FlagConstant
+from incremental import Version
 
 from twisted.internet.defer import Deferred
 from twisted.internet.error import VerifyError, CertificateError
@@ -215,12 +217,10 @@ from twisted.internet.interfaces import (
 from twisted.python import reflect, util
 from twisted.python.deprecate import _mutuallyExclusiveArguments
 from twisted.python.compat import nativeString, networkString, unicode
-from twisted.python.constants import Flags, FlagConstant
 from twisted.python.failure import Failure
 from twisted.python.util import FancyEqMixin
 
 from twisted.python.deprecate import deprecated
-from twisted.python.versions import Version
 
 
 def _sessionCounter(counter=itertools.count()):
@@ -263,7 +263,7 @@ def protocolNegotiationMechanisms():
 
     @return: A combination of flags from L{ProtocolNegotiationSupport} that
         indicate which mechanisms for protocol negotiation are supported.
-    @rtype: L{FlagConstant}
+    @rtype: L{constantly.FlagConstant}
     """
     support = ProtocolNegotiationSupport.NOSUPPORT
     ctx = SSL.Context(SSL.SSLv23_METHOD)
